package com.adventurer_engine.client.model.rc;

package .tmp;

import com.adventurer_engine.client.model.rc.EnumKeyFrameType;
import com.adventurer_engine.common.entity.neo_npc.AnimationController;
import com.adventurer_engine.common.entity.neo_npc.EntityRCsNPCBase;
import com.adventurer_engine.util.blockbench.BBModel;
import com.adventurer_engine.util.blockbench.BBModelAnimation;
import cpw.mods.fml.relauncher.Side;
import cpw.mods.fml.relauncher.SideOnly;
import java.util.List;
import org.lwjgl.opengl.GL11;

public class RCsAnimationManager extends AnimationController {
  public int tick = 0;
  
  public double maxTickTime;
  
  public String currentAnimation;
  
  public BBModel currentModel;
  
  private boolean isPlaying = false;
  
  protected boolean startAnimation() {
    if (!this.currentModel.animations.containsKey(this.currentAnimation))
      return false; 
    this.tick = 0;
    this.isPlaying = true;
    this.maxTickTime = ((BBModelAnimation)this.currentModel.animations.get(this.currentAnimation)).length * 20.0D;
    return true;
  }
  
  @SideOnly(Side.CLIENT)
  public boolean launchAnimation(String animationName, EntityRCsNPCBase npc) {
    if (animationName.equals(this.currentAnimation)) {
      startAnimation();
      return true;
    } 
    if (!npc.model.animations.containsKey(animationName))
      return false; 
    this.currentAnimation = animationName;
    this.currentModel = npc.model;
    return startAnimation();
  }
  
  public void onUpdate() {
    if (!this.isPlaying)
      return; 
    this.tick++;
    if (this.tick >= Math.ceil(this.maxTickTime))
      this.tick = 0; 
  }
  
  public void doRender(String boneUUID, float partialTicks, float magic) {
    if (!this.isPlaying)
      return; 
    BBModelAnimation.BBModelAnimator a = (BBModelAnimation.BBModelAnimator)((BBModelAnimation)this.currentModel.animations.get(this.currentAnimation)).animators.get(boneUUID);
    if (a == null)
      return; 
    handleKeyFrameList(a.positionChannel, partialTicks, magic, EnumKeyFrameType.POSITION);
    handleKeyFrameList(a.rotationChannel, partialTicks, magic, EnumKeyFrameType.ROTATION);
    handleKeyFrameList(a.scaleChannel, partialTicks, magic, EnumKeyFrameType.SCALE);
  }
  
  private void handleKeyFrameList(List<BBModelAnimation.KeyFrame> frames, float partialTicks, float magic, EnumKeyFrameType type) {
    if (frames.isEmpty())
      return; 
    double currentTick = this.tick;
    currentTick += partialTicks;
    int startFrame = 0, endFrame = 0;
    if (currentTick >= ((BBModelAnimation.KeyFrame)frames.get(frames.size() - 1)).time) {
      startFrame = frames.size() - 1;
      endFrame = frames.size() - 1;
    } else if (currentTick > ((BBModelAnimation.KeyFrame)frames.get(0)).time) {
      for (int i = 1; i < frames.size(); i++) {
        double startTime = ((BBModelAnimation.KeyFrame)frames.get(i - 1)).time;
        double endTime = ((BBModelAnimation.KeyFrame)frames.get(i)).time;
        if (currentTick >= startTime && currentTick <= endTime) {
          startFrame = i - 1;
          endFrame = i;
          break;
        } 
      } 
    } 
    if (startFrame == endFrame) {
      BBModelAnimation.KeyFrame frame = frames.get(startFrame);
      applyFrame(frame, frame.data_points, magic, type);
    } else {
      double[] data_points = new double[3];
      double[] start_points = ((BBModelAnimation.KeyFrame)frames.get(startFrame)).data_points;
      double[] end_points = ((BBModelAnimation.KeyFrame)frames.get(endFrame)).data_points;
      double startTime = ((BBModelAnimation.KeyFrame)frames.get(startFrame)).time;
      double endTime = ((BBModelAnimation.KeyFrame)frames.get(endFrame)).time;
      for (int i = 0; i < 3; i++) {
        double a = start_points[i];
        double b = end_points[i];
        double t0 = startTime;
        double t1 = endTime;
        double t = currentTick;
        data_points[i] = ((a - b) * t + t0 * b - t1 * a) / (t0 - t1);
      } 
      applyFrame(frames.get(endFrame), data_points, magic, type);
    } 
  }
  
  private void applyFrame(BBModelAnimation.KeyFrame frame, double[] data_points, float magic, EnumKeyFrameType type) {
    switch (null.$SwitchMap$com$adventurer_engine$client$model$rc$EnumKeyFrameType[type.ordinal()]) {
      case 1:
        GL11.glScalef((float)data_points[0], (float)data_points[1], (float)data_points[2]);
        break;
      case 2:
        if (data_points[2] != 0.0D)
          GL11.glRotatef((float)data_points[2], 0.0F, 0.0F, 1.0F); 
        if (data_points[1] != 0.0D)
          GL11.glRotatef((float)-data_points[1], 0.0F, 1.0F, 0.0F); 
        if (data_points[0] != 0.0D)
          GL11.glRotatef((float)-data_points[0], 1.0F, 0.0F, 0.0F); 
        break;
      case 3:
        GL11.glTranslatef(-((float)data_points[0]) * magic, (float)data_points[1] * magic, (float)data_points[2] * magic);
        break;
    } 
  }
}
